<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://mailto:sr.msilva@hotmail.com
 * @since      1.0.0
 *
 * @package    Custom_Pdf_Invoices
 * @subpackage Custom_Pdf_Invoices/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Custom_Pdf_Invoices
 * @subpackage Custom_Pdf_Invoices/admin
 * @author     Marcos Silva <sr.msilva@hotmail.com>
 */
class Custom_Pdf_Invoices_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Custom_Pdf_Invoices_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Custom_Pdf_Invoices_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/custom-pdf-invoices-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Custom_Pdf_Invoices_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Custom_Pdf_Invoices_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/custom-pdf-invoices-admin.js', array('jquery'), $this->version, false);
	}

	public function add_menus()
	{
		add_submenu_page('woocommerce', 'Faturas Campos Personalizados', 'Fatura Custom', 'manage_woocommerce', 'pdf-invoices-custom-fields', [$this, 'dashboard']);
	}
	public function dashboard()
	{

		require_once 'partials/custom-pdf-invoices-admin-display.php';
	}

	public function ajax_hooks()
	{
		add_action('wp_ajax_cpi_meta_fields', function () {

			$execute = $_POST['execute'] ?? false;

			$cpi_fields = get_option('cpi_custom_fields', []);

			switch ($execute) {
				case 'add':
					$cpi_fields[uniqid()] = ['val' => $_POST['val'] ?? '', 'key' => $_POST['key'] ?? ''];
					break;
				case 'delete':
					$id = $_POST['id'] ?? false;
					if ($id)
						unset($cpi_fields[$id]);
					break;
				case 'update':
					$id = $_POST['id'] ?? false;
					if ($id)
						$cpi_fields[$id] = ['val' => $_POST['val'] ?? '', 'key' => $_POST['key'] ?? ''];
					break;
			}

			update_option('cpi_custom_fields', $cpi_fields);

			echo json_encode($cpi_fields);

			wp_die();
		});
	}
}
