<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://mailto:sr.msilva@hotmail.com
 * @since      1.0.0
 *
 * @package    Custom_Pdf_Invoices
 * @subpackage Custom_Pdf_Invoices/admin/partials
 */

$alert = get_transient('cpi_create_template_info');
?>

<style>
    #cpi_app {
        font-family: sans-serif;
        font-size: 14px;
        padding: 10px;
        background-color: white;
        border: 1px solid #e1e1e1;
        margin: 0 auto;
        border-radius: 10px;
        margin-top: 30px;
    }

    #cpi_app input {
        padding: 8px;
        width: 200px;
        border: 1px solid #ccc;
        margin-bottom: 10px;
        font-family: sans-serif;
        font-size: 14px;
    }

    #cpi_app button {
        padding: 8px;
        background: #ccc;
        border: 1px solid #ccc;
        font-size: 14px;
        font-family: sans-serif;
        cursor: pointer;
    }

    #cpi_app ul {
        list-style: none;
        padding: 0;
        margin: 0;
    }

    #cpi_app li {
        padding: 10px;
        border-bottom: 1px solid #ccc;
    }

    #cpi_app h1 {
        margin-top: 10px;
    }

    .cpi_alert {
        background-color: lightgoldenrodyellow;
        padding: 10px;
        margin: 10px auto;
    }
</style>

<div class="" id="cpi_app">
    <div id="overlay" style="display: none; position: fixed; top: 0; left: 0; right: 0; bottom: 0; background-color: rgba(0, 0, 0, 0.5); z-index: 2;">
        <div style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); text-align: center;font-size: 2em;text-transform: uppercase;color: white;font-weight: bold;">
            Atualizando...
        </div>
    </div>
    <div class="manage-pdf-fields">
        <h1>Campos Personalizados Para a Invoice</h1>

        <?php if (!empty($alert)) : ?>
            <div class="cpi_alert">
                <h2><?php echo $alert; ?></h2>
            </div>
        <?php endif; ?>
        <div id="">
            <input placeholder="Key do Campo" type="text" id="todoKey" />
            <input placeholder="Nome de Exibição na Invoice" type="text" id="todoVal" />
            <button type="button" id="addTodo">Adicionar</button>
            <button type="button" id="updateTodo" style="display:none">Atualizar</button>
            <div id="todolist">
            </div>
        </div>
    </div>
</div>

<script>
    let cpi_meta_fields = {};

    document.addEventListener('DOMContentLoaded', function() {

        <?php
        $cpi_fields = get_option('cpi_custom_fields');
        if (!empty($cpi_fields)) : ?>
            cpi_load_data(`<?php echo json_encode($cpi_fields) ?>`);
        <?php endif; ?>
    });

    function showOverlay() {
        document.getElementById("overlay").style.display = "block";
    }

    function hideOverlay() {
        document.getElementById("overlay").style.display = "none";
    }

    function cpi_load_data(data) {
        cpi_meta_fields = JSON.parse(data);
        var todolistHTML = "<ul>";
        Object.entries(cpi_meta_fields).forEach(([id, item]) => {
            todolistHTML += "<li>" + item.key + ": " + item.val + " <button type='button' class='editTodo' data-id='" + id + "'>Editar</button> <button type='button' class='removeTodo' data-id='" + id + "'>Apagar</button></li>";
        });
        todolistHTML += "</ul>";

        jQuery("#todolist").html(todolistHTML);
    }

    (function($) {
        $(document).ready(function() {
            $("#addTodo").click(function() {
                var todoKey = $("#todoKey").val();
                var todoVal = $("#todoVal").val();

                showOverlay();
                $.post("admin-ajax.php", {
                    key: todoKey,
                    val: todoVal,
                    action: 'cpi_meta_fields',
                    execute: 'add'
                }, function(data) {
                    hideOverlay();
                    $("#todoKey").val("");
                    $("#todoVal").val("");

                    cpi_load_data(data);
                });
            });

            $(document).on("click", ".editTodo", function() {
                var id = $(this).data("id");
                $("#todoKey").val(cpi_meta_fields[id].key);
                $("#todoVal").val(cpi_meta_fields[id].val);
                $("#addTodo").hide();
                $("#updateTodo").show();
                currentId = id;
            });

            $(document).on("click", ".removeTodo", function() {

                showOverlay();
                var id = $(this).data("id");
                $.post("admin-ajax.php", {
                    id: id,
                    action: 'cpi_meta_fields',
                    execute: 'delete'
                }, function(data) {

                    hideOverlay();
                    cpi_load_data(data);

                });
            });

            $("#updateTodo").click(function() {

                showOverlay();

                var todoKey = $("#todoKey").val();
                var todoVal = $("#todoVal").val();
                $.post("admin-ajax.php", {
                    action: 'cpi_meta_fields',
                    execute: 'update',
                    id: currentId,
                    key: todoKey,
                    val: todoVal
                }, function(data) {

                    hideOverlay();
                    $("#updateTodo").hide();
                    $("#addTodo").show();
                    $("#todoKey").val("");
                    $("#todoVal").val("");

                    cpi_load_data(data);

                });
            });
        })
    })(jQuery);
</script>